GCMEncrypted constructor
const
GCMEncrypted({
- String? seedId,
Creates a GCM encryption hook for one or more string fields.
Implementation
const GCMEncrypted({this.seedId});
Creates a GCM encryption hook for one or more string fields.
const GCMEncrypted({this.seedId});