PhiveSeedProvider class abstract
Provides encryption seed material for hooks that need symmetric keys.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSeedSync(
String? seedId) → List< int> - Returns a key synchronously from memory. Expects init to have been called.
-
init(
) → Future< void> - Initializes the seeds dynamically.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited