TTLExpiredException class
Exception raised when a TTL-managed payload has expired on read.
- Implemented types
Constructors
- TTLExpiredException()
- Creates the standard PHive TTL expiry exception.
Properties
-
behaviors
→ Set<
PHiveActionBehavior> -
Composable side effects the router should apply when handling this error.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable explanation for the action failure or policy event.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns a compact log-friendly representation of the exception.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited